# Changelog

## Unreleased (2025-12-09)

#### New Features

* Add API and initiator basic support. Misc improvements
* Dynamic versions
* CI/CD to generate changelog
* Add pypi publishing
* Add sonarcloud configuration
#### Fixes

* Token management (WIP)
* improve token management
* Use a uuid as the client ID to prevent duplicate error
* Ensure CI builds correct version by handling conflicting git tags
* Subscribe to Document to avoid 'blinking' state
* update setuptools-scm configuration for proper version handling
* delete duplicate license
* change target branch to develop
* tests
#### Refactorings

* Mqtt connection
* Misc temporary refactors and fixes
#### Others

* Use prod URLs
* fix isort
* Flake8
* black
* Add versioning convention
* linting
* fix license
* Add doc warning
* Update badge links
* update readme
* deploy docs on eveything branches/pushes (test)
